Linchpin CLI
============

Linchpin Command line is a unified tool that provides a consistent interface for interacting with most of the features of Linchpin. Linchpin commands line interface is availble with the "linchpin" command, and comes installed with Linchpin automatically. The linchpin command has subcommands like linchpin rise , linchpin drop etc. 

In order view all the commands you can use linchpin --help .

.. toctree::
   :maxdepth: 1

   linchpincli_linchpin_config
   linchpincli_linchpin_init
   linchpincli_linchpin_rise
   linchpincli_linchpin_drop
   linchpincli_linchpin_topology
   linchpincli_linchpin_layout
   linchpincli_linchpin_validate
